@@ -604,15 +604,16 @@ class EmsLayer(object):
             logger.info("The attachments were deleted successfully.")
         return True
 
-    def download_attachment(self, feature_id, attachment_id):
-        # type: (int, int) -> bool
+    def download_attachment(self, feature_id, attachment_id, output_path=None):
+        # type: (int, int, Optional[str]) -> bool
         """
         Download the specified attachment
 
         Args:
             feature_id (int): The ID of the feature owning the attachment
             attachment_id (int): The attachments ID
-
+            output_path (str): Output directory where the attachment will be
+            saved
         Returns:
             bool: The result of the download attachment
         """
@@ -647,7 +648,18 @@ class EmsLayer(object):
                 filename = "no_name"
             logger.info("Saving attachment to {0}".format(filename))
 
-            with open(filename, "wb") as output_file:
+            if output_path:
+                if not os.path.exists(output_path):
+                    logger.error("The path {0} does not exist".format(output_path))
+                    return False
+
+                attachment_path = os.path.join(output_path, filename)
+
+            else:
+                attachment_path = filename
+
+            logger.debug("Saving attachment to {0}".format(attachment_path))
+            with open(attachment_path, "wb") as output_file:
                 output_file.write(response.content)
             return True
         else:
