@@ -76,7 +76,7 @@ class Service(object):
         >>> my_service.projects
 
     Emspy uses requests Session so the session will remain active until close()
-    is called.
+    is called.This will perform also a logout on Tomcat.
 
     Args:
 
@@ -171,9 +171,9 @@ class Service(object):
         url = "/".join([self.base_url, "rest"])
         try:
             response = requests.get(url)
-        except ValueError as exception:
+        except (ValueError, requests.exceptions.ConnectionError) as exception:
             logging.error(
-                "Login error. Please check username and password: %s", exception
+                "Error connecting to EMS Service for URL Testing: %s", exception
             )
             return False
         else:
@@ -531,5 +531,11 @@ class Service(object):
         """
         Close the session to the service.
         """
+        logout_url = "/".join([self.base_url, "logout.xhtml"])
+        response = self.session.get(logout_url)
+        if response.ok:
+            logger.info("Session closed.")
+        else:
+            logger.warn("Error logging out using url %s", logout_url)
         self.session.close()
         logger.info("Session closed.")
